
uniform sampler2DShadow shadowMap;

uniform sampler2D		textureToUse;
uniform int				useTexture;

uniform float shadowBias;

varying vec4 depthMapCoord;

varying vec3 normal;
varying vec3 eyeVertexPos;


void main() {

	vec4 depthCoord = depthMapCoord / depthMapCoord.w;
	//depthCoord.z -= 0.000001;	// anti-moire
	depthCoord.z += shadowBias;
				
	vec4 mapDepth = shadow2DProj(shadowMap, depthCoord , 0.0);
	 	
	
 	if(mapDepth.z < depthCoord.z && mapDepth.z < 1.0) {
		gl_Color = gl_LightSource[0].ambient * gl_FrontMaterial.ambient;
	}
	else {
	
	//  *********** LIGHTING *************
		normal = normalize(normal);
		
		vec3 eyeLightDir = normalize(gl_LightSource[0].position.xyz - eyeVertexPos);
				
		vec3 eyeLightDir1 = gl_LightSource[1].position.xyz - eyeVertexPos;
		float distanceLight1 = length(eyeLightDir1);
		eyeLightDir1 = normalize(eyeLightDir1);
		
		vec3 halfVector = normalize(eyeLightDir - eyeVertexPos);
		//vec3 halfVector = gl_NormalMatrix * gl_LightSource[0].halfVector.xyz;
		vec4 amb, diff, spec;
		amb		= gl_LightSource[0].ambient;
		diff	= gl_LightSource[0].diffuse * max(0.0 , dot(normal, eyeLightDir));
		spec	= gl_LightSource[0].specular * pow(max(0.0, dot(normal, halfVector)), gl_FrontMaterial.shininess);
		
		// light 2 (spotlight)
		vec3 halfVector1 = normalize(eyeLightDir1 - eyeVertexPos);
		float spotCosine = max(0.0 , dot(normalize(gl_LightSource[1].spotDirection), -eyeLightDir1));
		if(spotCosine > gl_LightSource[1].spotCosCutoff) {
			amb  += gl_LightSource[1].ambient;
			diff += gl_LightSource[1].diffuse * max(0.0 , dot(normal, eyeLightDir1)) / (distanceLight1 / 4.0);
			spec += gl_LightSource[1].specular * pow(max(0.0, dot(normal, halfVector1)), gl_FrontMaterial.shininess);
		}
			
		gl_Color =	gl_FrontMaterial.ambient * amb +
					gl_FrontMaterial.diffuse * diff +
					gl_FrontMaterial.specular * spec;
	}
	
	//  *********** TEXTURE *************
	
	if(useTexture == 1)
		gl_Color *= texture2D(textureToUse, gl_TexCoord[0].st);
	  	
	gl_FragColor = gl_Color;
}
